@@ -1,14 +1,14 @@
 import abc
 import asyncio
 import logging
-from types import MethodType
+from types import MethodType, ModuleType
 from typing import List, Optional
 
 from pydantic import BaseSettings
 
 from arrlio.models import Event, Message, TaskInstance, TaskResult
-from arrlio.serializer.base import Serializer
-from arrlio.tp import AsyncCallableT, SerializerT, TimeoutT
+from arrlio.serializers.base import Serializer
+from arrlio.tp import AsyncCallableT, SerializerT
 
 
 logger = logging.getLogger("arrlio")
@@ -17,13 +17,15 @@ logger = logging.getLogger("arrlio")
 class BackendConfig(BaseSettings):
     name: Optional[str]
     serializer: SerializerT
-    timeout: Optional[TimeoutT]
 
 
 class Backend(abc.ABC):
     def __init__(self, config: BackendConfig):
         self.config: BackendConfig = config
-        self.serializer: Serializer = config.serializer()
+        if isinstance(config.serializer, ModuleType):
+            self.serializer: Serializer = config.serializer.Serializer()
+        else:
+            self.serializer: Serializer = config.serializer()
         self._closed: asyncio.Future = asyncio.Future()
         self._tasks: set = set()
 
